@@ -16,7 +16,7 @@ use Cwd;
 ######################################################################
 #### Configuration Section
 
-$VERSION = '3.420';
+$VERSION = '3.423';
 
 # Basenames we should ignore when recursing directories,
 # Because they contain large files of no relevance
@@ -664,7 +664,8 @@ for downstream programs that also use Verilog::Getopt.
 =item $self->parameter ( \@params )
 
 Parses any recognized parameters in the referenced array, removing the
-standard parameters and returning a array with all unparsed parameters.
+standard parameters from any previous parameters() call, and returning a
+array with all unparsed parameters.
 
 The below list shows the VCS-like parameters that are supported, and the
 functions that are called:
@@ -793,7 +794,7 @@ Verilog-Perl is part of the L<http://www.veripool.org/> free Verilog EDA
 software tool suite.  The latest version is available from CPAN and from
 L<http://www.veripool.org/verilog-perl>.
 
-Copyright 2000-2016 by Wilson Snyder.  This package is free software; you
+Copyright 2000-2017 by Wilson Snyder.  This package is free software; you
 can redistribute it and/or modify it under the terms of either the GNU
 Lesser General Public License Version 3 or the Perl Artistic License Version 2.0.
 
